@@ -1,16 +1,23 @@
 import uuid
+from allauth.socialaccount.models import SocialAccount
 
 from django.apps import apps
 from django.test import TestCase
 from model_bakery import baker
-from simpl import get_game_experience_model, get_player_model, get_run_model
-from simpl.models import Lobby
+from simpl import (
+    get_game_experience_model,
+    get_instance_model,
+    get_player_model,
+    get_run_model,
+)
+from simpl.models import Lobby, BaseRun
+from django.contrib.auth import get_user_model
 
 
 class RunTest(TestCase):
     def setUp(self):
         Player = get_player_model()
-        self.simpl_run = baker.make(get_run_model(), game__name="Game")
+        self.simpl_run: BaseRun = baker.make(get_run_model(), game__name="Game")
         self.players = baker.make(
             Player, run=self.simpl_run, user__first_name="Julia", _quantity=3
         )
@@ -41,6 +48,14 @@ class RunTest(TestCase):
                 self.assertIn(player.character, characters)
                 self.assertEqual(player.character.user, player.user)
 
+    def test_get_or_create_multiplayer_instance_existing(self):
+        instance = baker.make(get_instance_model(), run=self.simpl_run)
+        lobby = baker.make(Lobby, run=self.simpl_run, instance=instance)
+
+        new_instance, created = self.simpl_run.get_or_create_multiplayer_instance(lobby)
+        self.assertFalse(created)
+        self.assertEqual(instance, new_instance)
+
     def test_prepare_single_player_run(self):
         self.simpl_run.multiplayer = False
         self.simpl_run.save()
@@ -168,3 +183,33 @@ class LobbyTestCase(TestCase):
         self.assertNumQueries(3)
         self.assertFalse(annotated_lobby.ready)
         self.assertNumQueries(3)
+
+
+class SocialAccountTestCase(TestCase):
+    def test_updates_user(self):
+        user = baker.make(get_user_model())
+        SocialAccount.objects.create(
+            extra_data={"first_name": "Bob", "family_name": "Jones"}, user=user
+        )
+        user.refresh_from_db()
+        self.assertEqual(user.first_name, "Bob")
+        self.assertEqual(user.last_name, "Jones")
+
+    def test_updates_user(self):
+        user = baker.make(get_user_model())
+        SocialAccount.objects.create(extra_data={}, user=user)
+        user_refreshed = get_user_model().objects.get()
+        self.assertEqual(user.first_name, user_refreshed.first_name)
+        self.assertEqual(user.last_name, user_refreshed.last_name)
+
+    def test_sets_user_email_if_empty(self):
+        user = baker.make(get_user_model(), email="")
+        SocialAccount.objects.create(extra_data={"email": "new@example.com"}, user=user)
+        user.refresh_from_db()
+        self.assertEqual(user.email, "new@example.com")
+
+    def test_dont_update_user_email(self):
+        user = baker.make(get_user_model(), email="old@example.com")
+        SocialAccount.objects.create(extra_data={"email": "new@example.com"}, user=user)
+        user_refreshed = get_user_model().objects.get()
+        self.assertEqual(user.email, user_refreshed.email)
